@@ -22,22 +22,18 @@
 from os.path import join
 from os.path import dirname
 
-import gtk
+from caribou import data_path
 
 # Application name
 APP_NAME = 'Caribou'
 APP_SLUG_NAME = 'caribou'
 
 # Paths
-DATA_DIR = join('/usr', 'share', '%s' % APP_SLUG_NAME)
-RESOURCES_DIR = join(DATA_DIR, 'resources')
-KEYBOARDS_DIR = join(RESOURCES_DIR, 'keyboards')
-CONFIG_DIR = join(RESOURCES_DIR, 'config')
-DATABASES_DIR = join(RESOURCES_DIR, 'databases')
-GLADE_UIS_DIR = join(RESOURCES_DIR, 'uis')
+DATA_DIR = data_path
+KEYBOARDS_DIR = join(DATA_DIR, 'keyboards')
 
 # Preferences
-CARIBOU_GCONF = join('/apps', 'caribou', 'osk')
+CARIBOU_GCONF = '/apps/caribou/osk'
 
 # Key types
 NORMAL_KEY_TYPE = 'normal'
@@ -45,17 +41,3 @@ LAYOUT_SWITCHER_KEY_TYPE = 'layout_switcher'
 PREFERENCES_KEY_TYPE = 'preferences'
 DUMMY_KEY_TYPE = 'dummy'
 MASK_KEY_TYPE = 'mask'
-
-KEY_MASKS = {'shift': gtk.gdk.SHIFT_MASK,
-             'lock': gtk.gdk.LOCK_MASK,
-             'control': gtk.gdk.CONTROL_MASK,
-             'mod1': gtk.gdk.MOD1_MASK,
-             'mod2': gtk.gdk.MOD2_MASK,
-             'mod3': gtk.gdk.MOD3_MASK,
-             'mod4': gtk.gdk.MOD4_MASK,
-             'mod5': gtk.gdk.MOD5_MASK,
-             'button1': gtk.gdk.BUTTON1_MASK,
-             'button2': gtk.gdk.BUTTON2_MASK,
-             'button3': gtk.gdk.BUTTON3_MASK,
-             'button4': gtk.gdk.BUTTON4_MASK,
-             'button5': gtk.gdk.BUTTON5_MASK}
